import { system, world } from '@minecraft/server';

let scoreboard = world.scoreboard

function hasEquipmentInSpecificSlots(player, itemID, slots) {
    for (let slot of slots) {
        const inv = player.getComponent('inventory').container.getItem(slot)
        if (inv?.typeId == itemID) {
            return true;
        }
    }
    return false;
}
function hasEquipmentSlot(player, itemID, slot) {
    let getEquipment = player.getComponent('equippable').getEquipment(slot)
    if (getEquipment?.typeId == itemID) {
        return true;
    }
}

world.afterEvents.playerSpawn.subscribe(ev => {
    let player = ev.player
    if (player.hasTag('cooldownPoison') || player.hasTag('cooldownWither') || player.hasTag('cooldownDarkness')) {
        player.removeTag('cooldownPoison')
        player.removeTag('cooldownWither')
        player.removeTag('cooldownDarkness')
    }
})
world.afterEvents.entityHurt.subscribe(ev => {
    let hurtEntity = ev.hurtEntity
    let slots = [16, 17, 25, 26, 34, 35]
    let item1 = "eu:poison_antidote"
    let item2 = "eu:wither_antidote"
    let item3 = "eu:darkness_antidote"
    let source = ev.damageSource

    if (hurtEntity.typeId != 'minecraft:player') {
        return;
    }
    if (hasEquipmentInSpecificSlots(hurtEntity, item1, slots) && hurtEntity.getEffect('poison') && !hurtEntity.hasTag('cooldownPoison')) {
        hurtEntity.addTag('cooldownPoison')
        system.runTimeout(() => {
            hurtEntity.runCommand('playsound random.eat')
            hurtEntity.removeEffect('poison')
            system.runTimeout(() => {
                hurtEntity.removeTag('cooldownPoison')
                hurtEntity.runCommand('playsound beacon.activate')

            }, 20 * 30)//default 30

        }, 20 * 3)
    }
    if (hasEquipmentInSpecificSlots(hurtEntity, item2, slots) && hurtEntity.getEffect('wither') && !hurtEntity.hasTag('cooldownWither')) {
        hurtEntity.addTag('cooldownWither')
        system.runTimeout(() => {
            hurtEntity.runCommand('playsound random.eat')
            hurtEntity.removeEffect('wither')
            system.runTimeout(() => {
                hurtEntity.removeTag('cooldownWither')
                hurtEntity.runCommand('playsound beacon.activate')

            }, 20 * 30)//default 30

        }, 20 * 3)
    }
    if (hasEquipmentInSpecificSlots(hurtEntity, item3, slots) && hurtEntity.getEffect('darkness') && !hurtEntity.hasTag('cooldownDarkness')) {
        hurtEntity.addTag('cooldownDarkness')
        system.runTimeout(() => {
            hurtEntity.runCommand('playsound random.eat')
            hurtEntity.removeEffect('darkness')
            system.runTimeout(() => {
                hurtEntity.removeTag('cooldownDarkness')
                hurtEntity.runCommand('playsound beacon.activate')

            }, 20 * 30)//default 30

        }, 20 * 3)
    }
})

///Baubles slot
system.runInterval(() => {
    /// 7, 8
    let slots = [16, 17, 25, 26, 34, 35]
    let item1 = "eu:heart_of_the_sea_amulet"
    let item2 = "eu:turtle_shell"
    let item3 = "eu:invisibility_cloak"
    let helmet1 = "eu:wildfire_helmet"
    let mainHand1 = "eu:antigravity_rock"
    for (const player of world.getPlayers()) {
        if (hasEquipmentInSpecificSlots(player, item1, slots) && player.isInWater) {
            player.addEffect('conduit_power', 20 * 15, { amplifier: 0, showParticles: false })
        }
        if (hasEquipmentInSpecificSlots(player, item2, slots)) {
            player.addEffect('resistance', 20 * 3, { amplifier: 0, showParticles: false })
        }
        if (hasEquipmentInSpecificSlots(player, item3, slots)) {
            player.addEffect('invisibility', 20 * 3, { amplifier: 0, showParticles: false })
        }
        if (hasEquipmentSlot(player, helmet1, 'Head')) {
            player.addEffect('fire_resistance', 20 * 15, { amplifier: 0, showParticles: false })
        }
        if (hasEquipmentSlot(player, mainHand1, 'Mainhand')) {
            player.addEffect('levitation', 20 * 2, { amplifier: 29, showParticles: false })
        }
    }
}, 20 * 1)

///yeah... I have been playing terraria

///crea un scoreboard si no existe al iniciar el mundo
world.afterEvents.worldInitialize.subscribe(() => {
    if (!scoreboard.getObjective("x") || !scoreboard.getObjective("y") || !scoreboard.getObjective("z")) {
        scoreboard.addObjective("x")
        scoreboard.addObjective("y")
        scoreboard.addObjective("z")
    }
})



///gracias por todo geopibe
world.afterEvents.itemUse.subscribe((ev) => {
    let player = ev.source
    let location = player.location
    let item = ev.itemStack
    let x
    let y
    let z

    if (item.typeId == "eu:magic_mirror" && !player.hasTag("tp")) {
        let dimensionTag = world.getDimension(`${player.dimension.id}`).id.replace("minecraft:", "")
        scoreboard.getObjective("x").setScore(player, Math.floor(location.x))
        scoreboard.getObjective("y").setScore(player, Math.floor(location.y))
        scoreboard.getObjective("z").setScore(player, Math.floor(location.z))
        player.removeTag(`dim:overworld`)
        player.removeTag(`dim:nether`)
        player.removeTag(`dim:the_end`)
        player.addTag(`dim:${dimensionTag}`)
        x = scoreboard.getObjective("x").getScore(player)
        y = scoreboard.getObjective("y").getScore(player)
        z = scoreboard.getObjective("z").getScore(player)
        player.sendMessage(`Saved Coordinates! x: ${x} y: ${y} z: ${z} dimension:${player.dimension.id.replace("minecraft:", "")}`);
        player.addTag("tp")

    } else if (item.typeId == "eu:magic_mirror" && player.hasTag("tp")) {
        let savedDim = player.getTags().filter(tag => tag.startsWith("dim:")).map(tag2 => tag2.replace("dim:", ""))
        x = scoreboard.getObjective("x").getScore(player)
        y = scoreboard.getObjective("y").getScore(player)
        z = scoreboard.getObjective("z").getScore(player)
        player.teleport({ x: x, y: y, z: z }, { dimension: world.getDimension(`${savedDim}`) })
        player.sendMessage(`Teleported to saved coordinates!`);
        player.removeTag("tp")
        ///player.getComponent('equippable').setEquipment('Mainhand', undefined)
    }
});

//on_consume Items
world.afterEvents.itemCompleteUse.subscribe(ev => {
    let player = ev.source
    let item = ev.itemStack
    let spawnPoint = player.getSpawnPoint()

    switch (item.typeId) {
        case 'eu:hellish_hot_pepper': {
            player.addEffect('fire_resistance', 20 * 15, { amplifier: 0 })
            player.addEffect('speed', 20 * 5, { amplifier: 0 })
            break;
        }
        case 'eu:green_apple': {
            player.addEffect('resistance', 20 * 10, { amplifier: 0 })
            break;
        }
        case 'eu:rage_potion': {
            player.addEffect('strength', 20 * 15, { amplifier: 1 })
            player.addEffect('speed', 20 * 15, { amplifier: 0 })
            player.addEffect('hunger', 20 * 15, { amplifier: 4 })
            break;
        }
        case 'eu:sculk_potion': {
            player.addEffect('resistance', 20 * 10, { amplifier: 9 })
            player.addEffect('blindness', 20 * 60, { amplifier: 0 })
            break;
        }
        case 'eu:ender_dust': {
            player.runCommand('spreadplayers ~ ~ 5 10 @s')
            break;
        }
        case 'eu:allay_dust': {
            player.addEffect('levitation', 20 * 10, { amplifier: 0 })
            break;
        }
        case 'eu:milk_potion': {
            player.removeEffect('hunger')
            player.removeEffect('darkness')
            player.removeEffect('blindness')
            player.removeEffect('fatal_poison')
            player.removeEffect('hunger')
            player.removeEffect('mining_fatigue')
            player.removeEffect('nausea')
            player.removeEffect('poison')
            player.removeEffect('slowness')
            player.removeEffect('fatal_poison')
            player.removeEffect('wither')
            player.removeEffect('weakness')
            break;
        }
        default: break;
    }

    if (!spawnPoint && item.typeId === "eu:recall_potion") {
        player.sendMessage("There is no save point!");
        player.getComponent('equippable').setEquipment('Mainhand', undefined)
        return;
    }

    if (item.typeId === "eu:recall_potion") {
        player.teleport(spawnPoint, { dimension: spawnPoint.dimension });
        player.sendMessage("You have teleported to your last save point!");
        player.getComponent('equippable').setEquipment('Mainhand', undefined)
    }
})

